@@ -51,7 +51,7 @@ protected:
 
 class BackupAction : public SyncAction
 {
-Q_OBJECT
+TQ_OBJECT
   
 
 public:
@@ -117,7 +117,7 @@ private:
 
 class FileInstallAction : public SyncAction
 {
-Q_OBJECT
+TQ_OBJECT
   
 public:
 	FileInstallAction(KPilotLink *,
@@ -145,7 +145,7 @@ private:
 
 class RestoreAction : public SyncAction
 {
-Q_OBJECT
+TQ_OBJECT
   
 public:
 	RestoreAction(KPilotLink *,TQWidget *w=0L);
