@@ -74,7 +74,7 @@ class KDE_EXPORT KPilotDeviceLink : public KPilotLink
 friend class PilotSerialDatabase;
 friend class DeviceCommThread;
 
-Q_OBJECT
+TQ_OBJECT
   
 
 public:
